@@ -1,7 +1,5 @@
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 4233 $
-# Date: $Date: 2005-12-29 00:48:48 +0100 (Thu, 29 Dec 2005) $
+# $Id: references.py 6167 2009-10-11 14:51:42Z grubert $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -242,7 +240,7 @@ class IndirectHyperlinks(Transform):
             del target.multiply_indirect
         if reftarget.hasattr('refuri'):
             target['refuri'] = reftarget['refuri']
-            if target.has_key('refid'):
+            if 'refid' in target:
                 del target['refid']
         elif reftarget.hasattr('refid'):
             target['refid'] = reftarget['refid']
@@ -259,7 +257,7 @@ class IndirectHyperlinks(Transform):
         target.resolved = 1
 
     def nonexistent_indirect_target(self, target):
-        if self.document.nameids.has_key(target['refname']):
+        if target['refname'] in self.document.nameids:
             self.indirect_target_error(target, 'which is a duplicate, and '
                                        'cannot be used as a unique reference')
         else:
@@ -282,7 +280,7 @@ class IndirectHyperlinks(Transform):
               'Indirect hyperlink target %s refers to target "%s", %s.'
               % (naming, target['refname'], explanation), base_node=target)
         msgid = self.document.set_id(msg)
-        for ref in uniq(reflist):
+        for ref in utils.uniq(reflist):
             prb = nodes.problematic(
                   ref.rawsource, ref.rawsource, refid=msgid)
             prbid = self.document.set_id(prb)
@@ -507,7 +505,7 @@ class Footnotes(Transform):
             while 1:
                 label = str(startnum)
                 startnum += 1
-                if not self.document.nameids.has_key(label):
+                if label not in self.document.nameids:
                     break
             footnote.insert(0, nodes.label('', label))
             for name in footnote['names']:
@@ -602,12 +600,12 @@ class Footnotes(Transform):
         """
         for footnote in self.document.footnotes:
             for label in footnote['names']:
-                if self.document.footnote_refs.has_key(label):
+                if label in self.document.footnote_refs:
                     reflist = self.document.footnote_refs[label]
                     self.resolve_references(footnote, reflist)
         for citation in self.document.citations:
             for label in citation['names']:
-                if self.document.citation_refs.has_key(label):
+                if label in self.document.citation_refs:
                     reflist = self.document.citation_refs[label]
                     self.resolve_references(citation, reflist)
 
@@ -668,11 +666,11 @@ class Substitutions(Transform):
         for ref in subreflist:
             refname = ref['refname']
             key = None
-            if defs.has_key(refname):
+            if refname in defs:
                 key = refname
             else:
                 normed_name = refname.lower()
-                if normed.has_key(normed_name):
+                if normed_name in normed:
                     key = normed[normed_name]
             if key is None:
                 msg = self.document.reporter.error(
@@ -688,14 +686,14 @@ class Substitutions(Transform):
                 subdef = defs[key]
                 parent = ref.parent
                 index = parent.index(ref)
-                if  (subdef.attributes.has_key('ltrim')
-                     or subdef.attributes.has_key('trim')):
+                if  ('ltrim' in subdef.attributes
+                     or 'trim' in subdef.attributes):
                     if index > 0 and isinstance(parent[index - 1],
                                                 nodes.Text):
                         parent.replace(parent[index - 1],
                                        parent[index - 1].rstrip())
-                if  (subdef.attributes.has_key('rtrim')
-                     or subdef.attributes.has_key('trim')):
+                if  ('rtrim' in subdef.attributes
+                     or 'trim' in subdef.attributes):
                     if  (len(parent) > index + 1
                          and isinstance(parent[index + 1], nodes.Text)):
                         parent.replace(parent[index + 1],
@@ -732,6 +730,14 @@ class Substitutions(Transform):
                         ref.replace_self(prb)
                 else:
                     ref.replace_self(subdef_copy.children)
+                    # register refname of the replacment node(s)
+                    # (needed for resolution of references)
+                    for node in subdef_copy.children:
+                        if isinstance(node, nodes.Referential):
+                            # HACK: verify refname attribute exists.
+                            # Test with docs/dev/todo.txt, see. |donate|
+                            if 'refname' in node:
+                                self.document.note_refname(node)
 
 
 class TargetNotes(Transform):
@@ -766,7 +772,7 @@ class TargetNotes(Transform):
                 continue
             footnote = self.make_target_footnote(target['refuri'], refs,
                                                  notes)
-            if not notes.has_key(target['refuri']):
+            if target['refuri'] not in notes:
                 notes[target['refuri']] = footnote
                 nodelist.append(footnote)
         # Take care of anonymous references.
@@ -776,13 +782,13 @@ class TargetNotes(Transform):
             if ref.hasattr('refuri'):
                 footnote = self.make_target_footnote(ref['refuri'], [ref],
                                                      notes)
-                if not notes.has_key(ref['refuri']):
+                if ref['refuri'] not in notes:
                     notes[ref['refuri']] = footnote
                     nodelist.append(footnote)
         self.startnode.replace_self(nodelist)
 
     def make_target_footnote(self, refuri, refs, notes):
-        if notes.has_key(refuri):  # duplicate?
+        if refuri in notes:  # duplicate?
             footnote = notes[refuri]
             assert len(footnote['names']) == 1
             footnote_name = footnote['names'][0]
@@ -875,7 +881,7 @@ class DanglingReferencesVisitor(nodes.SparseNodeVisitor):
                 if resolver_function(node):
                     break
             else:
-                if self.document.nameids.has_key(refname):
+                if refname in self.document.nameids:
                     msg = self.document.reporter.error(
                         'Duplicate target name, cannot be used as a unique '
                         'reference: "%s".' % (node['refname']), base_node=node)
@@ -896,11 +902,3 @@ class DanglingReferencesVisitor(nodes.SparseNodeVisitor):
             node.resolved = 1
 
     visit_footnote_reference = visit_citation_reference = visit_reference
-
-
-def uniq(L):
-     r = []
-     for item in L:
-         if not item in r:
-             r.append(item)
-     return r
