@@ -1,7 +1,6 @@
-# Authors:  David Goodger; Garth Kidd
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 4258 $
-# Date: $Date: 2006-01-09 04:29:23 +0100 (Mon, 09 Jan 2006) $
+# $Id: DocutilsTestSupport.py 6159 2009-10-09 07:17:59Z milde $
+# Authors: David Goodger <goodger@python.org>;
+#          Garth Kidd <garth@deadlybloodyserious.com>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -43,6 +42,11 @@ __docformat__ = 'reStructuredText'
 
 import sys
 import os
+import unittest
+import re
+import inspect
+import traceback
+from pprint import pformat
 
 testroot = os.path.abspath(os.path.dirname(__file__) or os.curdir)
 os.chdir(testroot)
@@ -50,27 +54,27 @@ sys.path.insert(0, os.path.normpath(os.path.join(testroot, '..')))
 sys.path.insert(0, testroot)
 sys.path.append(os.path.normpath(os.path.join(testroot, '..', 'extras')))
 
-import unittest
-import docutils_difflib
-import inspect
-from pprint import pformat
-from types import UnicodeType, StringType
-import package_unittest
-import docutils
-import docutils.core
-from docutils import frontend, nodes, statemachine, urischemes, utils
-from docutils.transforms import universal
-from docutils.parsers import rst
-from docutils.parsers.rst import states, tableparser, roles, languages
-from docutils.readers import standalone, pep
-from docutils.statemachine import StringList, string2lines
-
 try:
-    from docutils.readers.python import moduleparser
-    from tokenize import generate_tokens
-    del generate_tokens
-except ImportError:      # moduleparser depends on modules added in Python 2.2
-    moduleparser = None
+    import difflib
+    import package_unittest
+    import docutils
+    import docutils.core
+    from docutils import frontend, nodes, statemachine, urischemes, utils
+    from docutils.transforms import universal
+    from docutils.parsers import rst
+    from docutils.parsers.rst import states, tableparser, roles, languages
+    from docutils.readers import standalone, pep
+    from docutils.statemachine import StringList, string2lines
+    from docutils._compat import bytes
+except ImportError:
+    # The importing module (usually __init__.py in one of the
+    # subdirectories) may catch ImportErrors in order to detect the
+    # absence of DocutilsTestSupport in sys.path.  Thus, ImportErrors
+    # resulting from problems with importing Docutils modules must
+    # caught here.
+    traceback.print_exc()
+    sys.exit(1)
+
 
 try:
     import mypdb as pdb
@@ -136,7 +140,7 @@ class CustomTestCase(StandardTestCase):
     see the compare_output method and the parameter list of __init__.
     """
 
-    compare = docutils_difflib.Differ().compare
+    compare = difflib.Differ().compare
     """Comparison method shared by all subclasses."""
 
     def __init__(self, method_name, input, expected, id, run_in_debugger=0,
@@ -157,7 +161,7 @@ class CustomTestCase(StandardTestCase):
         self.input = input
         self.expected = expected
         self.run_in_debugger = run_in_debugger
-        self.suite_settings = suite_settings or {}
+        self.suite_settings = suite_settings.copy() or {}
         
         # Ring your mother.
         unittest.TestCase.__init__(self, method_name)
@@ -185,12 +189,20 @@ class CustomTestCase(StandardTestCase):
 
     def compare_output(self, input, output, expected):
         """`input`, `output`, and `expected` should all be strings."""
-        if isinstance(input, UnicodeType):
+        if isinstance(input, unicode):
             input = input.encode('raw_unicode_escape')
-        if isinstance(output, UnicodeType):
-            output = output.encode('raw_unicode_escape')
-        if isinstance(expected, UnicodeType):
-            expected = expected.encode('raw_unicode_escape')
+        if sys.version_info > (3,):
+            # API difference: Python 3's node.__str__ doesn't escape
+            #assert expected is None or isinstance(expected, unicode)
+            if isinstance(expected, bytes):
+                expected = expected.decode('ascii')
+            if isinstance(output, bytes):
+                output = output.decode('ascii')
+        else:
+            if isinstance(expected, unicode):
+                expected = expected.encode('raw_unicode_escape')
+            if isinstance(output, unicode):
+                output = output.encode('raw_unicode_escape')
         try:
             self.assertEquals(output, expected)
         except AssertionError, error:
@@ -607,6 +619,12 @@ class PythonModuleParserTestCase(CustomTestCase):
     def test_parser(self):
         if self.run_in_debugger:
             pdb.set_trace()
+        try:
+            import compiler
+        except ImportError:
+            # skip on Python 3
+            return
+        from docutils.readers.python import moduleparser
         module = moduleparser.parse_module(self.input, 'test data').pformat()
         output = str(module)
         self.compare_output(self.input, output, self.expected)
@@ -614,6 +632,12 @@ class PythonModuleParserTestCase(CustomTestCase):
     def test_token_parser_rhs(self):
         if self.run_in_debugger:
             pdb.set_trace()
+        try:
+            import compiler
+        except ImportError:
+            # skip on Python 3
+            return
+        from docutils.readers.python import moduleparser
         tr = moduleparser.TokenParser(self.input)
         output = tr.rhs(1)
         self.compare_output(self.input, output, self.expected)
@@ -625,17 +649,6 @@ class PythonModuleParserTestSuite(CustomTestSuite):
     A collection of PythonModuleParserTestCase.
     """
 
-    notified = None
-
-    def __init__(self, *args, **kwargs):
-        if moduleparser is None:
-            if not self.notified:
-                print ('Tests of docutils.readers.python skipped; '
-                       'Python 2.2 or higher required.')
-                PythonModuleParserTestSuite.notified = 1
-            self.generateTests = self.generate_no_tests
-        CustomTestSuite.__init__(self, *args, **kwargs)
-
     def generateTests(self, dict, dictname='totest',
                       testmethod='test_parser'):
         """
@@ -674,7 +687,7 @@ class WriterPublishTestCase(CustomTestCase, docutils.SettingsSpec):
     writer_name = '' # set in subclasses or constructor
 
     def __init__(self, *args, **kwargs):
-        if kwargs.has_key('writer_name'):
+        if 'writer_name' in kwargs:
             self.writer_name = kwargs['writer_name']
             del kwargs['writer_name']
         CustomTestCase.__init__(self, *args, **kwargs)
@@ -769,7 +782,6 @@ class HtmlWriterPublishPartsTestCase(WriterPublishTestCase):
         # interpolate standard variables:
         expected = self.expected % {'version': docutils.__version__}
         self.compare_output(self.input, output, expected)
-
     
     standard_content_type_template = ('<meta http-equiv="Content-Type"'
                                       ' content="text/html; charset=%s" />\n')
@@ -787,10 +799,17 @@ class HtmlWriterPublishPartsTestCase(WriterPublishTestCase):
 
     def format_output(self, parts):
         """Minimize & standardize the output."""
-        # remove redundant parts:
+        # remove redundant parts & uninteresting parts:
         del parts['whole']
         assert parts['body'] == parts['fragment']
         del parts['body']
+        del parts['body_pre_docinfo']
+        del parts['body_prefix']
+        del parts['body_suffix']
+        del parts['head']
+        del parts['head_prefix']
+        del parts['encoding']
+        del parts['version']
         # remove standard portions:
         parts['meta'] = parts['meta'].replace(self.standard_meta_value, '')
         parts['html_head'] = parts['html_head'].replace(
@@ -807,19 +826,19 @@ class HtmlWriterPublishPartsTestCase(WriterPublishTestCase):
         output = []
         for key in keys:
             output.append("%r: '''%s'''"
-                          % (key, parts[key].encode('raw_unicode_escape')))
+                          % (key, parts[key]))
             if output[-1].endswith("\n'''"):
                 output[-1] = output[-1][:-4] + "\\n'''"
         return '{' + ',\n '.join(output) + '}\n'
 
 
-def exception_data(code):
+def exception_data(func, *args, **kwds):
     """
-    Execute `code` and return the resulting exception, the exception arguments,
-    and the formatted exception string.
+    Execute `func(*args, **kwds)` and return the resulting exception, the
+    exception arguments, and the formatted exception string.
     """
     try:
-        exec(code)
+        func(*args, **kwds)
     except Exception, detail:
         return (detail, detail.args,
                 '%s: %s' % (detail.__class__.__name__, detail))
@@ -844,20 +863,21 @@ def _format_str(*args):
 
     This is a helper function for CustomTestCase.
     """
-    import re
     return_tuple = []
     for i in args:
         r = repr(i)
-        if ( (isinstance(i, StringType) or isinstance(i, UnicodeType))
+        if ( (isinstance(i, str) or isinstance(i, unicode))
              and '\n' in i):
             stripped = ''
-            if isinstance(i, UnicodeType):
-                # stripped = 'u' or 'U'
+            if isinstance(i, unicode) and r.startswith('u'):
+                stripped = r[0]
+                r = r[1:]
+            elif isinstance(i, bytes) and r.startswith('b'):
                 stripped = r[0]
                 r = r[1:]
             # quote_char = "'" or '"'
             quote_char = r[0]
-            assert quote_char in ("'", '"')
+            assert quote_char in ("'", '"'), quote_char
             assert r[0] == r[-1]
             r = r[1:-1]
             r = (stripped + 3 * quote_char + '\\\n' +
