@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_tables.py 5499 2008-01-14 15:52:01Z goodger $
+# $Id: test_tables.py 6010 2009-07-05 15:29:02Z goodger $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -11,10 +11,9 @@ Tests for tables.py directives.
 from __init__ import DocutilsTestSupport
 
 import os
-try:
-    import csv
-except ImportError:
-    csv = None
+import csv
+from docutils._compat import u_prefix
+from docutils.parsers.rst.directives import tables
 
 
 def suite():
@@ -28,21 +27,21 @@ utf_16_csv_rel = DocutilsTestSupport.utils.relative_path(None, utf_16_csv)
 empty_txt = os.path.join(mydir, 'empty.txt')
 
 unichr_exception = DocutilsTestSupport.exception_data(
-    'unichr(int("9999999999999", 16))')[0]
+    unichr, int("9999999999999", 16))[0]
 if isinstance(unichr_exception, OverflowError):
     unichr_exception_string = 'code too large (%s)' % unichr_exception
 else:
     unichr_exception_string = str(unichr_exception)
 
-null_bytes_code = """
-import csv
-import cStringIO
-csv_data = open('%s', 'rb').read()
-csv_file = cStringIO.StringIO(csv_data)
-reader = csv.reader(csv_file)
-reader.next()
-""" % utf_16_csv
-null_bytes_exception = DocutilsTestSupport.exception_data(null_bytes_code)[0]
+def null_bytes():
+    import csv
+    csv_data = open(utf_16_csv, 'rb').read()
+    csv_data = unicode(csv_data, 'latin1').splitlines()
+    reader = csv.reader([tables.CSVTable.encode_for_csv(line + '\n')
+                         for line in csv_data])
+    reader.next()
+
+null_bytes_exception = DocutilsTestSupport.exception_data(null_bytes)[0]
 
 totest = {}
 
@@ -178,11 +177,7 @@ totest['table'] = [
 """],
 ]
 
-if not csv:
-    print ('Tests of "csv-table" directive skipped; '
-           'Python 2.3 or higher required.')
-else:
-    totest['csv-table'] = [
+totest['csv-table'] = [
 ["""\
 .. csv-table:: inline with integral header
    :widths: 10, 20, 30
@@ -562,11 +557,12 @@ u"""\
     <system_message level="4" line="1" source="test data" type="SEVERE">
         <paragraph>
             Problems with "csv-table" directive path:
-            [Errno 2] No such file or directory: 'bogus.csv'.
+            [Errno 2] No such file or directory: %s'bogus.csv'.
         <literal_block xml:space="preserve">
             .. csv-table:: no such file
                :file: bogus.csv
-"""],
+""" % u_prefix],
+# note that this output is rewritten below for certain python versions
 ["""\
 .. csv-table:: bad URL
    :url: bogus.csv
@@ -631,7 +627,7 @@ u"""\
                :widths: 0 0 0
             \n\
                some, csv, data
-""" % DocutilsTestSupport.exception_data('int("y")')[1][0]],
+""" % DocutilsTestSupport.exception_data(int, "y")[1][0]],
 ["""\
 .. csv-table:: good delimiter
    :delim: /
@@ -1074,6 +1070,18 @@ totest['list-table'] = [
 ]
 
 
+if csv:
+    # Rewrite csv tests that depend on the output of IOError as it is
+    # platform-dependent before python 2.4 for a unicode path.
+    # Here only needed for python 2.3 on non-windows
+    import sys
+    if sys.version_info < (2, 4) and not sys.platform.startswith('win'):
+        for i in range(len(totest['csv-table'])):
+            if totest['csv-table'][i][1].find("u'bogus.csv'") != -1:
+                totest['csv-table'][i][1] = totest['csv-table'][i][1].replace(
+                        "u'bogus.csv'", "'bogus.csv'")
+
+
 if __name__ == '__main__':
     import unittest
     unittest.main(defaultTest='suite')
