@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# $Id: test_east_asian_text.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: test_east_asian_text.py 5889 2009-04-01 20:00:21Z gbrandl $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -17,6 +17,8 @@ try:
 except AttributeError:
     east_asian_width = None
 
+from docutils._compat import b
+
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
@@ -179,7 +181,7 @@ Some ambiguous-width characters:
 ⇔ left-right double arrow
 = ===================================
 """,
-u"""\
+b("""\
 <document source="test data">
     <paragraph>
         Some ambiguous-width characters:
@@ -307,7 +309,7 @@ u"""\
                     <entry>
                         <paragraph>
                             left-right double arrow
-"""],
+""").decode('raw_unicode_escape')],
 ]
 '''
 [u"""\
