@@ -1,9 +1,7 @@
 #! /usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 3160 $
-# Date: $Date: 2005-04-03 01:12:06 +0200 (Sun, 03 Apr 2005) $
+# $Id: test_tables.py 4647 2006-07-04 16:56:11Z wiemann $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -570,7 +568,7 @@ No blank line after table.
 | to accommodate long filesystem paths.)                                       |
 +------------------------------------------------------------------------------+
 """) % ('\n'.join(['|    %-70s    |' % include2[part * 70 : (part + 1) * 70]
-                   for part in range(len(include2) / 70 + 1)])),
+                   for part in range(len(include2) // 70 + 1)])),
 """\
 <document source="test data">
     <table>
@@ -605,7 +603,7 @@ Something afterwards.
 
 And more.
 """) % ('\n'.join(['|    %-70s    |' % include2[part * 70 : (part + 1) * 70]
-                   for part in range(len(include2) / 70 + 1)])),
+                   for part in range(len(include2) // 70 + 1)])),
 """\
 <document source="test data">
     <paragraph>
@@ -1223,7 +1221,7 @@ Note       The first row of this table may expand
            to accommodate long filesystem paths.
 =========  =====================================================================
 """ % ('\n'.join(['              %-65s' % include2[part * 65 : (part + 1) * 65]
-                  for part in range(len(include2) / 65 + 1)])),
+                  for part in range(len(include2) // 65 + 1)])),
 """\
 <document source="test data">
     <table>
