@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: test_publisher.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: test_publisher.py 5889 2009-04-01 20:00:21Z gbrandl $
 # Author: Martin Blais <blais@furius.ca>
 # Copyright: This module has been placed in the public domain.
 
@@ -9,10 +9,10 @@ Test the `Publisher` facade and the ``publish_*`` convenience functions.
 """
 
 import pickle
-from types import StringType, DictType
 import DocutilsTestSupport              # must be imported before docutils
 import docutils
 from docutils import core, nodes, io
+from docutils._compat import b, bytes, u_prefix
 
 
 test_document = """\
@@ -21,7 +21,7 @@ Test Document
 
 This is a test document with a broken reference: nonexistent_
 """
-pseudoxml_output = """\
+pseudoxml_output = b("""\
 <document ids="test-document" names="test\ document" source="<string>" title="Test Document">
     <title>
         Test Document
@@ -35,9 +35,9 @@ pseudoxml_output = """\
         <system_message backrefs="id2" ids="id1" level="3" line="4" source="<string>" type="ERROR">
             <paragraph>
                 Unknown target name: "nonexistent".
-"""
-exposed_pseudoxml_output = """\
-<document ids="test-document" internal:refnames="{u\'nonexistent\': [<reference: <#text: u\'nonexistent\'>>]}" names="test\ document" source="<string>" title="Test Document">
+""")
+exposed_pseudoxml_output = b("""\
+<document ids="test-document" internal:refnames="{%s\'nonexistent\': [<reference: <#text: \'nonexistent\'>>]}" names="test\ document" source="<string>" title="Test Document">
     <title>
         Test Document
     <paragraph>
@@ -50,7 +50,7 @@ exposed_pseudoxml_output = """\
         <system_message backrefs="id2" ids="id1" level="3" line="4" source="<string>" type="ERROR">
             <paragraph>
                 Unknown target name: "nonexistent".
-"""
+""" % u_prefix)
 
 
 class PublishDoctreeTestCase(DocutilsTestSupport.StandardTestCase, docutils.SettingsSpec):
@@ -96,7 +96,7 @@ class PublishDoctreeTestCase(DocutilsTestSupport.StandardTestCase, docutils.Sett
            reader_name='doctree', source_class=io.DocTreeInput,
            source=doctree, source_path='test', writer_name='html',
            settings_spec=self)
-        self.assert_(isinstance(parts, DictType))
+        self.assert_(isinstance(parts, dict))
 
     def test_publish_pickle(self):
         # Test publishing a document tree with pickling and unpickling.
@@ -122,7 +122,7 @@ class PublishDoctreeTestCase(DocutilsTestSupport.StandardTestCase, docutils.Sett
         doctree.transformer = None
 
         doctree_pickled = pickle.dumps(doctree)
-        self.assert_(isinstance(doctree_pickled, StringType))
+        self.assert_(isinstance(doctree_pickled, bytes))
         del doctree
 
         # Unpickle the document.
