@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: rst2latex.py 4564 2006-05-21 20:44:42Z wiemann $
+# $Id: rst2latex.py 5905 2009-04-16 12:04:49Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -14,10 +14,13 @@ try:
 except:
     pass
 
-from docutils.core import publish_cmdline, default_description
-
+from docutils.core import publish_cmdline
 
 description = ('Generates LaTeX documents from standalone reStructuredText '
-               'sources.  ' + default_description)
+               'sources. '
+               'Reads from <source> (default is stdin) and writes to '
+               '<destination> (default is stdout).  See '
+               '<http://docutils.sourceforge.net/docs/user/latex.html> for '
+               'the full reference.')
 
 publish_cmdline(writer_name='latex', description=description)
